from repository import Repository, Publication


def list_authors(authors_list):
    for i, (lastname, firstname) in enumerate(authors_list, 1):
        print("{:02d}. {}, {}".format(i, lastname, firstname))


def list_publications(publications):
    for i, publication in enumerate(publications, 1): 
        print("{:02d}. {}, {}, {}, {}, {}".format(i, *publication))


def get_author_name():

    lastname = input("Enter author's last name: ")
    firstname = input("Enter author's first name: ")
    return (lastname, firstname)
    
    
def get_author_from_list(repo):
    authors = repo.get_authors_list()
    print("Select an author from the list")
    list_authors(authors)
    option = int(input('> '))  
    if option > 0 and option <= len(authors):
        return authors[option - 1]
    else:
        return None


def add_publication(repo):
    lastname, firstname = get_author_name()
    year = int(input('Enter publication year: '))
    title = input('Enter publication title: ')
    publisher = input('Enter publisher name: ')
    
    publication = Publication(lastname, firstname, year, title, publisher)
    status = repo.add(publication)
    if status:
        print("    Publication accepted")
    else:
        print("    Publication rejected")
    
    
def delete_publication(repo):
    fullname = get_author_from_list(repo)
    if fullname:
        publications = repo.get_publications_list(fullname)
        print("Select a publication from the list")
        list_publications(publications)
        option = int(input('> '))  
        if option > 0 and option <= len(publications):
            publication = publications[option - 1]
            repo.delete(publication)
            print("    Publication deleted")
        else:
            print("Invalid menu item")
    else:
        print("Invalid menu item")
    
    
def display_authors(repo):
    
    print("    Authors list")
    list_authors(repo.get_authors_list())


def display_publications(repo):
    
    fullname = get_author_from_list(repo)
    if fullname:
        publications = repo.get_publications_list(fullname)
        print("    Publications by {1} {0}".format(*fullname))
        list_publications(publications)
    else:
        print("Invalid menu item")


# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #


repo = Repository()
repo.load_csv('1530112302_DADSA_RESIT_CWK_JULY_2018.csv')

actions = {'1': add_publication, '2': delete_publication, 
           '3': display_authors, '4': display_publications}

while True:

    print('')
    print('1. Add Publication')
    print('2. Delete Publication')
    print('3. List Authors')
    print('4. List Publications')
    print('5. Exit') 
    
    option = input('> ')
    
    if option in actions:
        actions[option](repo)
    elif option == '5':
        break
    else:
        print("Invalid menu option")
        
        
